#!/bin/sh

# change the major version if needed
KDE_MAJOR_VER=4

NAME='gitsvn_move-rename'
VERSION='1.1'

MENU_1="
[Desktop Entry]
Actions=gitmoverename;svnmoverename
Comment=Plugin for svn/git move/rename
Icon=kdesvnmove
MimeType=all/all
Type=Service
X-KDE-ServiceTypes=KonqPopupMenu/Plugin,all/allfiles
X-KDE-Submenu=GitSVN Move/Rename
X-KDE-Submenu[it]=GITSVN Sposta/rinomina"

MENU_2="
[Desktop Entry]
Actions=svnmoverenamebrowser;gitmoverenamebrowser
Comment=Plugin for svn/git move/rename (browse)
Icon=kdesvnmove
MimeType=all/all
Type=Service
X-KDE-ServiceTypes=KonqPopupMenu/Plugin,all/allfiles
X-KDE-Submenu=GITSVN Move (Browse)
X-KDE-Submenu[it]=GITSVN Sposta (Browse)"

MENU_ENTRY_GIT="
[Desktop Action gitmoverename]
Exec=%s/$NAME.sh '%s' 'git'
Icon=kdesvnmove
Name=GIT Move/Rename
Name[it]=GIT Sposta/Rinomina"

MENU_ENTRY_SVN="
[Desktop Action svnmoverename]
Exec=%s/$NAME.sh '%s' 'svn'
Icon=kdesvnmove
Name=SVN Move/Rename
Name[it]=SVN Sposta/Rinomina"

MENU_ENTRY_2_GIT="
[Desktop Action gitmoverenamebrowser]
Exec=%s/$NAME.sh '%s' 'git' 'b'
Icon=kdesvnmove
Name=GIT Move to
Name[it]=GIT Sposta in"

MENU_ENTRY_2_SVN="
[Desktop Action svnmoverenamebrowser]
Exec=%s/$NAME.sh '%s' 'svn' 'b'
Icon=kdesvnmove
Name=SVN Move to
Name[it]=SVN Sposta in"

GIT_BIN="`which git 2>/dev/null`"
SVN_BIN="`which svn 2>/dev/null`"

HAVEGIT=0
HAVESVN=0

##
##
##

function get_install_info()
{
   if [ -z "$GIT_BIN" -a -z "$SVN_BIN" ]; then
      echo "===================================================="
      echo "$0: error: neither GIT nor SVN were found."
      echo "The installation can not continue!"
      echo "===================================================="
      exit 1
   fi

   if [ -z $GIT_BIN ]; then
      echo "-------------------------------------------------------------------------"
      echo "Warning: GIT was not found. The menu entry for GIT will not be installed."
      echo "Ignore this warning if actually you do not have it."
      echo "-------------------------------------------------------------------------"
      HAVEGIT=1
   fi

   if [ -z $SVN_BIN ]; then
      echo "-------------------------------------------------------------------------"
      echo "Warning: SVN was not found. The menu entry for SVN will not be installed."
      echo "Ignore this warning If actually you do not have it."
      echo "-------------------------------------------------------------------------"
      HAVESVN=1
   fi

   [ $KDE_MAJOR_VER -lt 4 ] && kdestr='kde' || kdestr='kde4'
   kdeconfig=$kdestr-config

   if ( test "$UID" -eq "0" ); then
      INSTALL_TYPE='global'
      kdedirpath="`$kdeconfig --prefix 2>/dev/null`"
   else
      INSTALL_TYPE='local'
      kdedirpath="`$kdeconfig --localprefix 2>/dev/null`"
   fi

   if [ -z "$kdedirpath" ]; then
      echo "========================================================"
      echo "$0: a $INSTALL_TYPE installation of KDE was not found."
      echo "The installation can not continue!"
      echo "========================================================"
      exit 1
   fi

   BIN_DIR=${kdedirpath}/bin
   SRV_DIR="${kdedirpath}/share/$kdestr/services/"

   echo -ne                                                     \
      "\n=====================================================" \
      "\nInstallation of the service '$NAME' v$VERSION"         \
      "\n=====================================================" \
      "\n\nType of installation:\t$INSTALL_TYPE"                \
      "\nService directory:\t$SRV_DIR"                          \
      "\nBinary directory:\t$BIN_DIR\n"
}

##
##
##

function install_service()
{
   # menu
   echo -e "$MENU_1" > $NAME.desktop
   echo -e "$MENU_2" > $NAME-browse.desktop

   # entries
   if [ $HAVEGIT -eq 0 ]; then
      printf "$MENU_ENTRY_GIT" "$BIN_DIR" "%f\n" >> $NAME.desktop
      printf "$MENU_ENTRY_2_GIT" "$BIN_DIR" "%f\n" >> $NAME-browse.desktop
   fi
   if [ $HAVESVN -eq 0 ]; then
      printf "$MENU_ENTRY_SVN" "$BIN_DIR" "%f\n" >> $NAME.desktop
      printf "$MENU_ENTRY_2_SVN" "$BIN_DIR" "%f\n" >> $NAME-browse.desktop
   fi

   [ "$INSTALL_TYPE" = "local" ] && mkdir -p $BIN_DIR
   install -m 755 $NAME.sh $BIN_DIR
   install -m 644 *.desktop $SRV_DIR

   echo
   echo "-------------------------"
   echo "Service is now installed."
   echo "-------------------------"
}

##
##
##

function uninstall()
{
   [ $KDE_MAJOR_VER -lt 4 ] && kdestr='kde' || kdestr='kde4'
   kdeconfig="$kdestr-config"

   test "$UID" -eq "0"                               && \
      kdedirpath="`$kdeconfig --prefix 2>/dev/null`" || \
      kdedirpath="`$kdeconfig --localprefix 2>/dev/null`"

   if [ -n $kdedirpath ]; then
      rm -f $kdedirpath/bin/$NAME.sh
      rm -f $kdedirpath/share/$kdestr/services/$NAME.desktop
      rm -f $kdedirpath/share/$kdestr/services/$NAME-browse.desktop
   fi

   rm -f $NAME.desktop $NAME-browse.desktop
}

##
## Main
##

[ "$1" != "uninstall" ] && get_install_info && install_service && exit 0
uninstall

exit 0